==> component-data-table-1.2.8.tgz: package/es/MoveRowButtons.js <==
import React from 'react';
import { Icon } from '@cloudflare/component-icon';
import { Div } from '@cloudflare/elements';
import { Button, ButtonGroup } from '@cloudflare/component-button';
import { useI18n } from '@cloudflare/intl-react';
const ICON_SIZE = 16;

const MoveRowButtons = ({
  describedBy = [],
  handleMoveUpClick,
  handleMoveDownClick
}) => {
  const _useI18n = useI18n(),
        t = _useI18n.t;

  const ariaDescribedBy = describedBy.join(' ');
  return /*#__PURE__*/React.createElement(ButtonGroup, null, /*#__PURE__*/React.createElement(Button, {
    px: 1,
    py: 1,
    "aria-describedby": ariaDescribedBy,
    ariaLabel: t('common.table.move_up'),
    disabled: handleMoveUpClick === undefined,
    onClick: handleMoveUpClick
  }, /*#__PURE__*/React.createElement(Div, {
    transform: "rotate(90deg)",
    display: "inline-block",
    width: ICON_SIZE,
    height: ICON_SIZE
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "backward",
    label: false
  }))), /*#__PURE__*/React.createElement(Button, {
    px: 1,
    py: 1,
    ml: "1px",
    "aria-describedby": ariaDescribedBy,
    ariaLabel: t('common.table.move_down'),
    disabled: handleMoveDownClick === undefined,
    onClick: handleMoveDownClick
  }, /*#__PURE__*/React.createElement(Div, {
    transform: "rotate(90deg)",
    display: "inline-block",
    width: ICON_SIZE,
    height: ICON_SIZE
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "forward",
    label: false
  }))));
};

export default MoveRowButtons;

==> component-data-table-4.0.1.tgz: package/es/MoveRowButtons.js <==
import React from 'react';
import { Icon } from '@cloudflare/component-icon';
import { Div } from '@cloudflare/elements';
import { Button, ButtonGroup } from '@cloudflare/component-button';
import { useI18n } from '@cloudflare/intl-react';
var ICON_SIZE = 16;

var MoveRowButtons = _ref => {
  var {
    describedBy = [],
    handleMoveUpClick,
    handleMoveDownClick
  } = _ref;
  var {
    t
  } = useI18n();
  var ariaDescribedBy = describedBy.join(' ');
  return /*#__PURE__*/React.createElement(ButtonGroup, null, /*#__PURE__*/React.createElement(Button, {
    px: 1,
    py: 1,
    "aria-describedby": ariaDescribedBy,
    ariaLabel: t('common.table.move_up'),
    disabled: handleMoveUpClick === undefined,
    onClick: handleMoveUpClick
  }, /*#__PURE__*/React.createElement(Div, {
    transform: "rotate(90deg)",
    display: "inline-block",
    width: ICON_SIZE,
    height: ICON_SIZE
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "backward",
    label: false
  }))), /*#__PURE__*/React.createElement(Button, {
    px: 1,
    py: 1,
    ml: "1px",
    "aria-describedby": ariaDescribedBy,
    ariaLabel: t('common.table.move_down'),
    disabled: handleMoveDownClick === undefined,
    onClick: handleMoveDownClick
  }, /*#__PURE__*/React.createElement(Div, {
    transform: "rotate(90deg)",
    display: "inline-block",
    width: ICON_SIZE,
    height: ICON_SIZE
  }, /*#__PURE__*/React.createElement(Icon, {
    type: "forward",
    label: false
  }))));
};

export default MoveRowButtons;
